@@ -1,5 +1,8 @@
 var NAVTREEINDEX2 =
 {
+"group__aom__encoder.html#gad09f5b034137ba0981dd5f2dc075b27f":[12,1,0,0,56],
+"group__aom__encoder.html#gad69c1d6aa10530991eeb1a3f0a818cba":[12,1,0,0,85],
+"group__aom__encoder.html#gadb34e02e5b029504370f99a886371710":[12,1,0,0,58],
 "group__aom__encoder.html#gadbb2fdd04ce113cdf455a6ea49109d41":[12,1,0,0,73],
 "group__aom__encoder.html#gadc27bac35ec9960f115ff1d060c75eba":[12,1,0,0,78],
 "group__aom__encoder.html#gae272ed6e69ae2a12993565e8176d004b":[12,1,0,0,31],
@@ -24,6 +27,7 @@ var NAVTREEINDEX2 =
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0a1d54150968c5c20b410bc29dc0caa4":[12,1,0,0,82,85],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0c45a2184ff7068f470cb9f128c3605d":[12,1,0,0,82,96],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0df0d30e82bb9683f3131138dfa2949a":[12,1,0,0,82,7],
+"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a0f45675bdc3e343a7ede3c9bba2c4456":[12,1,0,0,82,140],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a174ffbc2e91a020a8225900e38894137":[12,1,0,0,82,23],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a17b924cadd3c942f9e57fe6fc4d5e2ab":[12,1,0,0,82,10],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a17bd297efc31082157785d68fc5a6067":[12,1,0,0,82,28],
@@ -48,6 +52,7 @@ var NAVTREEINDEX2 =
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a353037d84b6c47ac0138fa843b70a2bb":[12,1,0,0,82,58],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a374b5581d0b68d5f8cc3e3f73495cfbb":[12,1,0,0,82,50],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3bf579936cd7dc5e0a35e10e40a96ce9":[12,1,0,0,82,132],
+"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3c14bacf43a485a98e6038d0f62df891":[12,1,0,0,82,139],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3e59c51f12c7350fee92c1c0d4901ab0":[12,1,0,0,82,91],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3ec44c6d8987ca88f8f635b7c098c11e":[12,1,0,0,82,27],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a3f494511b35631e4d400f4df9a48c6dc":[12,1,0,0,82,60],
@@ -60,6 +65,7 @@ var NAVTREEINDEX2 =
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a49c0eb54ab5a4d7d6cbc97d97f3029f8":[12,1,0,0,82,54],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4c1444fdafd3577606cef60afb33124c":[12,1,0,0,82,62],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4c4ae7f4158f795667b16c99fcdc5dd3":[12,1,0,0,82,82],
+"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4dcc855f5982be01742d7b17bbfebe39":[12,1,0,0,82,137],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a4fefd9e9d131485429e6c48bd5d439cf":[12,1,0,0,82,48],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a501a9453d5790f32c001e9877d3db40c":[12,1,0,0,82,103],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a518cc32bbf169f8e9d4d71e7c1193748":[12,1,0,0,82,64],
@@ -71,6 +77,7 @@ var NAVTREEINDEX2 =
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a57f2f2a54f593b398a5e97db7982f817":[12,1,0,0,82,22],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a5afff92787c68c2b5c50e3cfb9938504":[12,1,0,0,82,55],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a5e82346d8463bf758967abb0d03ebc88":[12,1,0,0,82,70],
+"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a637ebd78bd66a38f22e6d149192c35ed":[12,1,0,0,82,138],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a643067b985c437490d6248decad39235":[12,1,0,0,82,74],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a65f19811dc9057230d991647fac243b0":[12,1,0,0,82,39],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a6810fa1bb5b3b9a58063006e1f894542":[12,1,0,0,82,124],
@@ -82,6 +89,7 @@ var NAVTREEINDEX2 =
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a72c1d1e8be8ce0dd3f9b95751ec73acd":[12,1,0,0,82,135],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a737368591a37417b108c0706f7510885":[12,1,0,0,82,29],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a784231ebe03cdcd4ad77a2e3f7f0343e":[12,1,0,0,82,127],
+"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a7a1fb96b3ea0dcfb9e35737ce8009f20":[12,1,0,0,82,136],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a7d462f767d5feea411c70229a3d39508":[12,1,0,0,82,41],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a7dc089179d789c690c91c5eb6ef6f626":[12,1,0,0,82,71],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a80b982970499968059e878d56e34ed2a":[12,1,0,0,82,68],
@@ -220,18 +228,19 @@ var NAVTREEINDEX2 =
 "group__codecs.html":[12,1],
 "group__coefficient__coding.html":[12,2,5],
 "group__coefficient__coding.html#ga0076c2c06ae74fd7b00193d4aa2f1d46":[12,2,5,4],
-"group__coefficient__coding.html#ga1618c5468421234169f9b285bc70a59c":[12,2,5,12],
+"group__coefficient__coding.html#ga1618c5468421234169f9b285bc70a59c":[12,2,5,13],
 "group__coefficient__coding.html#ga1f9147fbeb6681f1f2ffd99806c93526":[12,2,5,0],
-"group__coefficient__coding.html#ga225614c4ff1863904ee8a80e0d971cc4":[12,2,5,11],
+"group__coefficient__coding.html#ga225614c4ff1863904ee8a80e0d971cc4":[12,2,5,12],
 "group__coefficient__coding.html#ga24b28c5ec4bc705cc58a7655c8218e4d":[12,2,5,3],
 "group__coefficient__coding.html#ga2afb7e8b3781bec12c44908fc5eaff51":[12,2,5,2],
+"group__coefficient__coding.html#ga4bd51731afdd25275377807e067c9d12":[12,2,5,7],
 "group__coefficient__coding.html#ga50e1752ad80721912848f6087b7b1025":[12,2,5,5],
-"group__coefficient__coding.html#ga8bc502fea9846765fba7de6a8fd90279":[12,2,5,9],
-"group__coefficient__coding.html#ga99f06925f4adb19ffb5fcbc12745ab94":[12,2,5,10],
-"group__coefficient__coding.html#gab27521d24faa93e58a1ce487b1e8f626":[12,2,5,8],
+"group__coefficient__coding.html#ga8bc502fea9846765fba7de6a8fd90279":[12,2,5,10],
+"group__coefficient__coding.html#ga99f06925f4adb19ffb5fcbc12745ab94":[12,2,5,11],
+"group__coefficient__coding.html#gab27521d24faa93e58a1ce487b1e8f626":[12,2,5,9],
 "group__coefficient__coding.html#gabb195b5ee31923fbd15fe4caaf466278":[12,2,5,1],
 "group__coefficient__coding.html#gad0c28d34dad6636237409bf2e1ee2014":[12,2,5,6],
-"group__coefficient__coding.html#gae0b8d3b37b0b43f1cfbd0f91cc4cc991":[12,2,5,7],
+"group__coefficient__coding.html#gae0b8d3b37b0b43f1cfbd0f91cc4cc991":[12,2,5,8],
 "group__cyclic__refresh.html":[12,2,9],
 "group__cyclic__refresh.html#ga10d1500b07ed1047288473605c079a9c":[12,2,9,7],
 "group__cyclic__refresh.html#ga1e8e194fae8285692651fb856b49c185":[12,2,9,2],
@@ -240,14 +249,5 @@ var NAVTREEINDEX2 =
 "group__cyclic__refresh.html#ga3703e9a518f8f17e7b6b601a456dbde8":[12,2,9,1],
 "group__cyclic__refresh.html#gaa4acc60c7ec3fc459b5ce65920493823":[12,2,9,6],
 "group__cyclic__refresh.html#gab14ed0139e8ebd0177d8a4b9c1e273ce":[12,2,9,8],
-"group__cyclic__refresh.html#gab63536700b85e6560aed37f0b8afbcaf":[12,2,9,5],
-"group__cyclic__refresh.html#gafb17f1befe613fac6ceebb9b5b24ebd8":[12,2,9,3],
-"group__cyclic__refresh.html#gafc1304a44c092d497a6cbbbaef92d1b9":[12,2,9,10],
-"group__decoder.html":[12,0,0],
-"group__decoder.html#ga23378c7ca8c361c097181aaaa2a5a734":[12,0,0,4],
-"group__decoder.html#ga2544bac9fdc439f0effd6b1b14df54be":[12,0,0,10],
-"group__decoder.html#ga2b456cf67b1b64dabed370c5d7514b29":[12,0,0,11],
-"group__decoder.html#ga67b2d2d0bfa394bbbd1c5ce4876ed48c":[12,0,0,7],
-"group__decoder.html#ga9ee6dac1fc46ab5c254395eea5469d5d":[12,0,0,13],
-"group__decoder.html#gab03fdb999d1f83a5896869a3ba5f68f7":[12,0,0,12]
+"group__cyclic__refresh.html#gab63536700b85e6560aed37f0b8afbcaf":[12,2,9,5]
 };
