@@ -1,48 +1,83 @@
 var NAVTREEINDEX8 =
 {
-"structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0":[13,0,66,62],
+"structcfg__options.html#aa1ccf6bfa7fe9a29ea514b99e7700d68":[12,0,1,4,14],
+"structcfg__options.html#aab0e968a76c1dd31fbfdee7b099b7828":[12,0,1,4,28],
+"structcfg__options.html#abf48d913552cb6b4f35ffdaf988c5dd8":[12,0,1,4,1],
+"structcfg__options.html#acb29ce1ad5f0043243627205225be5d7":[12,0,1,4,22],
+"structcfg__options.html#ad5b8e644bb93bb8f4dfc5bfb5326d88f":[12,0,1,4,16],
+"structcfg__options.html#ae272b61a508fcfcc32821ea842e30946":[12,0,1,4,8],
+"structcfg__options.html#ae789f357675eac91443a0dd4cd3902cb":[12,0,1,4,30],
+"structcfg__options.html#aee79cc8a5704b00f72e47aa6e4991b22":[12,0,1,4,13],
+"structmacroblock.html":[13,0,66],
+"structmacroblock.html#a00c8c8d03fa0236917ca3e6485f5f0c5":[13,0,66,14],
+"structmacroblock.html#a031b3ac15e79ebba99e3e3c86c7a1133":[13,0,66,39],
+"structmacroblock.html#a045f36d0d8a27dcd8be792f5cdcdd3b0":[13,0,66,3],
+"structmacroblock.html#a07e39b2368528999366be1ea379f50e0":[13,0,66,19],
+"structmacroblock.html#a099a8be27fac5a66f655471c91eb2d93":[13,0,66,12],
+"structmacroblock.html#a0de89964c4b6f0c74b9a74c494a8f6e4":[13,0,66,18],
+"structmacroblock.html#a13dbc93111a73a4bf0ac7f4598fe89d9":[13,0,66,44],
+"structmacroblock.html#a16078d24dc96053b119488652280e9d0":[13,0,66,60],
+"structmacroblock.html#a165159d92c9f6d7c4ec1b8ad6c47f4f0":[13,0,66,23],
+"structmacroblock.html#a17fb11d3bc68a52d9d0bfbd024237cf6":[13,0,66,42],
+"structmacroblock.html#a1bfbaf644bed64fcdc41119e2da0843f":[13,0,66,15],
+"structmacroblock.html#a228e767c53ab8ab4d8bfe446d33de98e":[13,0,66,17],
+"structmacroblock.html#a22c8a3380f06cf7061181e1ba5de5d5a":[13,0,66,1],
+"structmacroblock.html#a23d3a28fb6cc558faf0328711dee1eed":[13,0,66,69],
+"structmacroblock.html#a25f1da53d124bef096fd810a931ebbe7":[13,0,66,27],
+"structmacroblock.html#a2768397e93e4a74a5bb41380262a937f":[13,0,66,65],
+"structmacroblock.html#a279e29c928b7865495dfb116a3bcc54f":[13,0,66,26],
+"structmacroblock.html#a28abfde9e8cc5098b84aa609605cce4e":[13,0,66,37],
+"structmacroblock.html#a2a5f8b9affa29e2e6f02d438cff7389d":[13,0,66,4],
+"structmacroblock.html#a322458f98de370f8d8f0c86c39f603f8":[13,0,66,63],
+"structmacroblock.html#a33897e5529b5ae465aef0fd748c9bf1d":[13,0,66,46],
+"structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0":[13,0,66,66],
 "structmacroblock.html#a37f1df249ef1e12f57b9bfa2786aa086":[13,0,66,11],
-"structmacroblock.html#a3c8ed6c74a25055e311a476b5ad4702c":[13,0,66,18],
-"structmacroblock.html#a3dfb9d2b763d7184960693890017c703":[13,0,66,32],
-"structmacroblock.html#a3e33844a3bb8cb9c20dbf3b1f03005c9":[13,0,66,48],
-"structmacroblock.html#a3ff9e34d5b99575864a4278e105ecdd2":[13,0,66,37],
-"structmacroblock.html#a41dd07e2cc09c9aefdb24018f610a20e":[13,0,66,63],
-"structmacroblock.html#a4bd7c7bad1d4df3e10039f4c5e6a8b7e":[13,0,66,53],
-"structmacroblock.html#a4cecb2383140b5ce465a3ddcfb774a32":[13,0,66,55],
-"structmacroblock.html#a511c27f29e6b6e905539fda6518d6d2d":[13,0,66,23],
-"structmacroblock.html#a51dab6ebd0f86d088d772101895bc207":[13,0,66,46],
+"structmacroblock.html#a3c8ed6c74a25055e311a476b5ad4702c":[13,0,66,20],
+"structmacroblock.html#a3dfb9d2b763d7184960693890017c703":[13,0,66,36],
+"structmacroblock.html#a3e33844a3bb8cb9c20dbf3b1f03005c9":[13,0,66,52],
+"structmacroblock.html#a3ff9e34d5b99575864a4278e105ecdd2":[13,0,66,41],
+"structmacroblock.html#a40cd7e1964cc73f0e54e3e429feefbe0":[13,0,66,31],
+"structmacroblock.html#a41dd07e2cc09c9aefdb24018f610a20e":[13,0,66,67],
+"structmacroblock.html#a4bd7c7bad1d4df3e10039f4c5e6a8b7e":[13,0,66,57],
+"structmacroblock.html#a4cecb2383140b5ce465a3ddcfb774a32":[13,0,66,59],
+"structmacroblock.html#a511c27f29e6b6e905539fda6518d6d2d":[13,0,66,25],
+"structmacroblock.html#a51dab6ebd0f86d088d772101895bc207":[13,0,66,50],
+"structmacroblock.html#a54fe4d282d137868d98adc7ad7abb9dd":[13,0,66,16],
 "structmacroblock.html#a5616dd030329ca191ce1a31200459473":[13,0,66,10],
-"structmacroblock.html#a5b8fc24effcd5f082a0fad4efb1b0f7c":[13,0,66,41],
-"structmacroblock.html#a5c84d87000da6a479c483aceee12f346":[13,0,66,20],
-"structmacroblock.html#a6124c3e97a13d6823ff16d5d044b8ddf":[13,0,66,52],
+"structmacroblock.html#a5af7a6d5609fc762b77b82f5a7e5c14b":[13,0,66,35],
+"structmacroblock.html#a5b8fc24effcd5f082a0fad4efb1b0f7c":[13,0,66,45],
+"structmacroblock.html#a5c84d87000da6a479c483aceee12f346":[13,0,66,22],
+"structmacroblock.html#a6124c3e97a13d6823ff16d5d044b8ddf":[13,0,66,56],
 "structmacroblock.html#a646112bcb60cf889bdfefc2c213086ec":[13,0,66,9],
-"structmacroblock.html#a6c723b72e1d1111363753927ac8b53e7":[13,0,66,29],
+"structmacroblock.html#a6c723b72e1d1111363753927ac8b53e7":[13,0,66,33],
 "structmacroblock.html#a764c3f23fd2e1d581a1265bad933c196":[13,0,66,0],
-"structmacroblock.html#a850c0783f1fc99a8e1c74e6dcf9be7ae":[13,0,66,49],
-"structmacroblock.html#a8740e0b4847a0367ce2a42d9715bb4aa":[13,0,66,54],
+"structmacroblock.html#a850c0783f1fc99a8e1c74e6dcf9be7ae":[13,0,66,53],
+"structmacroblock.html#a8740e0b4847a0367ce2a42d9715bb4aa":[13,0,66,58],
 "structmacroblock.html#a90eeb3bb2b16490acc010bff8cd69f4a":[13,0,66,8],
-"structmacroblock.html#a914187a1e2c4ac2e7bbc63164dcd822e":[13,0,66,28],
-"structmacroblock.html#a93a3d8ca33457be296259242776453cd":[13,0,66,47],
-"structmacroblock.html#a9fddc59fbcf0e867e336a8d51b54a984":[13,0,66,51],
+"structmacroblock.html#a914187a1e2c4ac2e7bbc63164dcd822e":[13,0,66,32],
+"structmacroblock.html#a93a3d8ca33457be296259242776453cd":[13,0,66,51],
+"structmacroblock.html#a9fddc59fbcf0e867e336a8d51b54a984":[13,0,66,55],
 "structmacroblock.html#aac7182bb34bf1ca7c57b5ca0acdf085f":[13,0,66,6],
-"structmacroblock.html#aacddc7a61db595038479414a3139e19b":[13,0,66,60],
+"structmacroblock.html#aacddc7a61db595038479414a3139e19b":[13,0,66,64],
 "structmacroblock.html#aada35cc4d590ca2912c3305d49d1e460":[13,0,66,13],
-"structmacroblock.html#aae99f1ac179f073272682dcf6da0e410":[13,0,66,39],
-"structmacroblock.html#ab55de0eba1eebc220f37fa94bf1cf13a":[13,0,66,26],
-"structmacroblock.html#ab9a918c78e2a823a6aa234c32d6b4c48":[13,0,66,36],
-"structmacroblock.html#abe2b85272a08056fb6332699d350fe98":[13,0,66,19],
-"structmacroblock.html#ac8455bcc2b83854f86be71bf5f1a3137":[13,0,66,58],
-"structmacroblock.html#ad36d4b9e8b99944c6d5c312f241b348d":[13,0,66,30],
-"structmacroblock.html#ad64d6927d6567fa6a6c29f2e8fb444af":[13,0,66,50],
-"structmacroblock.html#adb20ef0cebd61dc8a468f5b928f27a10":[13,0,66,22],
+"structmacroblock.html#aae99f1ac179f073272682dcf6da0e410":[13,0,66,43],
+"structmacroblock.html#ab0acd9f744836c691dfbd612ce909b59":[13,0,66,30],
+"structmacroblock.html#ab55de0eba1eebc220f37fa94bf1cf13a":[13,0,66,28],
+"structmacroblock.html#ab9a918c78e2a823a6aa234c32d6b4c48":[13,0,66,40],
+"structmacroblock.html#abe2b85272a08056fb6332699d350fe98":[13,0,66,21],
+"structmacroblock.html#ac8455bcc2b83854f86be71bf5f1a3137":[13,0,66,62],
+"structmacroblock.html#ad36d4b9e8b99944c6d5c312f241b348d":[13,0,66,34],
+"structmacroblock.html#ad456641e8b4e392bf16b91d7277a2936":[13,0,66,68],
+"structmacroblock.html#ad64d6927d6567fa6a6c29f2e8fb444af":[13,0,66,54],
+"structmacroblock.html#adb20ef0cebd61dc8a468f5b928f27a10":[13,0,66,24],
 "structmacroblock.html#adbcb7d6e4e0fbe5180f62dd9d2d9d8a3":[13,0,66,5],
-"structmacroblock.html#adf2150137ef87e1a400bf29b3d0556b6":[13,0,66,45],
+"structmacroblock.html#adf2150137ef87e1a400bf29b3d0556b6":[13,0,66,49],
 "structmacroblock.html#ae1c34d0f490e6fde5878029e6446664e":[13,0,66,7],
-"structmacroblock.html#aebb266e0d877a120976d2933b297ebee":[13,0,66,43],
-"structmacroblock.html#aec74d7a69efa704dfa7b2669e8ae00d7":[13,0,66,27],
-"structmacroblock.html#aec77ad10388c3c6d4c2c6c2cc5f68e97":[13,0,66,44],
-"structmacroblock.html#aedba3047d9e9acf711eba686fa0e121f":[13,0,66,57],
-"structmacroblock.html#af2e92ae69af37f651668a7b31cd26e29":[13,0,66,34],
+"structmacroblock.html#aebb266e0d877a120976d2933b297ebee":[13,0,66,47],
+"structmacroblock.html#aec74d7a69efa704dfa7b2669e8ae00d7":[13,0,66,29],
+"structmacroblock.html#aec77ad10388c3c6d4c2c6c2cc5f68e97":[13,0,66,48],
+"structmacroblock.html#aedba3047d9e9acf711eba686fa0e121f":[13,0,66,61],
+"structmacroblock.html#af2e92ae69af37f651668a7b31cd26e29":[13,0,66,38],
 "structmacroblock.html#af9333e247364df6c3e316bf5ad221b56":[13,0,66,2],
 "structmacroblock__plane.html":[13,0,67],
 "structmacroblock__plane.html#a0ac98be27958cfdfc3daa1fb143d75f4":[13,0,67,2],
@@ -122,11 +157,11 @@ var NAVTREEINDEX8 =
 "structmotion__mode__candidate.html#ac6f3da66fe08484f3d3c9ce932aeaf17":[13,0,75,0],
 "structmotion__mode__candidate.html#ae1e3e7679dcc7e82d2520156c80f3c60":[13,0,75,3],
 "structyv12__buffer__config.html":[13,0,100],
-"svc__layercontext_8h_source.html":[14,0,2,2,21],
-"temporal__filter_8h_source.html":[14,0,2,2,22],
-"tpl__model_8h_source.html":[14,0,2,2,23],
-"tx__search_8h_source.html":[14,0,2,2,24],
-"txb__rdopt_8h_source.html":[14,0,2,2,25],
+"svc__layercontext_8h_source.html":[14,0,2,2,22],
+"temporal__filter_8h_source.html":[14,0,2,2,23],
+"tpl__model_8h_source.html":[14,0,2,2,24],
+"tx__search_8h_source.html":[14,0,2,2,25],
+"txb__rdopt_8h_source.html":[14,0,2,2,26],
 "usage.html":[6],
 "usage.html#usage_ctxs":[6,0,0],
 "usage.html#usage_errors":[6,3],
@@ -137,6 +172,6 @@ var NAVTREEINDEX8 =
 "usage_decode.html":[6,4],
 "usage_decode.html#usage_frame_iter":[6,4,0],
 "usage_encode.html":[6,5],
-"var__based__part_8h_source.html":[14,0,2,2,26],
+"var__based__part_8h_source.html":[14,0,2,2,27],
 "yv12config_8h_source.html":[14,0,1,0]
 };
